@@ -1,6 +1,6 @@
 "names.gp" <-
 function(x,...){
   # print out names of object components
-  ls(env=x)
+  ls(envir=x)
 }
 
